#include "auth.h"
#include <crypt.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>

#define MAX_PW_LEN 64

static const char m_passwd_file[] = "/etc/autoproc.pw";

static int auth_readpw(char *dest);


/**
 * \brief Reads the encrypted password from the password file.
 */
static int auth_readpw(char *dest)
{
    FILE *f;
    int rv = 0;
    
    f = fopen(m_passwd_file, "r");
    if (f != NULL)
    {
	rv = fscanf(f, "%40s", dest);
	fclose(f);
    }
    return rv;
}


/**
 * \brief Check if a given password is correct.
 *
 * \param pw Password to be checked
 * \return 1 if password is OK, else 0.
 */
int auth_verifyPasswd(const char *pw)
{
    char pw_file[MAX_PW_LEN];
    char *pw_user;
    int rv = 0;

    rv = auth_readpw(pw_file);
    if (rv > 0)
    {
	pw_user = crypt(pw, pw_file);
	rv = (!strcmp(pw_user, pw_file));
    }
    return rv;
}


/**
 * \brief Returns the name of the password file.
 */
const char *auth_get_passwd_file() 
{
    return m_passwd_file;
}


















