/* -*-C-*- */
#ifndef CONFIGURATION_H
#define CONFIGURATION_H

#include <sys/types.h>
#include "environment.h"

#define OPTIONS_LEN_ENV 32		/**< Maximal number of Environment variables */
#define OPTIONS_LEN_FNAME 512		/**< Maximal length of File name  */ 

/**
 * \file configuration.h
 * \brief Configurable parameters for Autoprocd.
 *
 * The configuration controls the behaviour of autoprocd.
 * This module defines the structure Configuration and
 * supplies functions to work with it. 
 */

/**
 * \brief A structure which contains configuration options.
 */
typedef struct {

    double max_cpuload;			/**< Maximal CPU load used by controlled processes */
    int max_load_intv;			/**< Maximal tolerated number of subsequent update intervals
					 where CPU load >=  max */
    uid_t uid;				/**< Autoprocd's user ID */
    gid_t gid;				/**< Autoprocd's group ID */
    float update_interval;			/**< Update interval for process data */
    int local;				/**< If true, don't open network sockets network access */
    int port;				/**< IP port number on which autoprocd listens. */
    unsigned int unix_socket_permissions;		/**< Access mode for UNIX socket. */
    char init_command[OPTIONS_LEN_FNAME];	/**< Path of initialization command. */
    char pid_file[OPTIONS_LEN_FNAME];	/**< Where to store the process ID. */
    char authentication;			/**< Authentication requirements. */

    char log_syslog_enabled; 		/**< If != 0, print log messages to syslog */
    int log_syslog_level;			/**< Syslog log level */

    /* Maybe extend this for rotating files. */
    Array *environment;			/**< Array of environment variables */

} Configuration;

void configuration_add_environment(Configuration *opt, const char *attr, const char *value);
void configuration_set_attribute(Configuration *opt, const char *attr, const char *value);

Configuration *configuration_create();
void configuration_destroy(Configuration *conf);
void configuration_clear(Configuration *conf);
void configuration_set_defaults(Configuration *conf);

#endif
