#include "connection.h"
#include "setup.h"
#include "pth.h"
#include <stdio.h>
#include <string.h>
#include "log.h"

/**
 * \brief Check for correct authentication.
 *
 * This function returns 1 if either this connection
 * has been authenticated or no authentication is needed
 * for the given level.
 */
int connection_check_auth_level(ConnectionData *cd, int level)
{
    int rv = 0;

    rv = ((cd->authOK) || (setup_get_configuration()->authentication < level));
    if (!rv) log_warning("Unauthorized Access");

    return rv;
}


/**
 * \brief Prints a message to a connection's file desciptor.
 * \param cd Connection data.
 * \param msg Message.
 */
void connection_print(ConnectionData *cd, const char* msg) 
{
    pth_write(cd->fd, msg, strlen(msg));
}

/**
 * \brief Prints a message to a connection's file desciptor.
 * \param cd Connection data.
 * \param msg Message.
 */
void connection_println(ConnectionData *cd, const char* msg) 
{
    pth_write(cd->fd, msg, strlen(msg));
    pth_write(cd->fd, "\n", strlen("\n"));
}

#define OUTPUT_BUFFER_SIZE 128
/**
 * \brief Prints formatted output to a connection's file descriptor. 
 */
void connection_printf(ConnectionData *cd, const char *format, ...) 
{
    char output_buffer[OUTPUT_BUFFER_SIZE]; /* NOT static! (threads) */
    va_list args;
    va_start(args, format);
    vsnprintf(output_buffer, OUTPUT_BUFFER_SIZE,format, args);
    va_end(args);
    pth_write(cd->fd, output_buffer, strlen(output_buffer));
}

/**
 * \brief Initializes connection data.
 */
void connection_init(ConnectionData *cd) 
{
    cd->fd = 0;
    cd->authOK= 0;
}

