/* -*-C-*- */
#ifndef CONNECTION_H
#define CONNECTION_H

/**
 * \file connection.h
 *
 * \brief Connection-related functions.
 *
 * The module connection contains data
 * types and functions which are used idn socket-based connections.
 * A connection consists of a file descriptor and an authentication
 * status. The authentication status is true (=1) if a password
 * authentication was successful within this connection. Password authentication
 * may or may not be needed, depending on the operation (read/write) and
 * the configuration (see AuthMode). 
 *
 */

/**
 * \brief File descriptor and authentication status for a socket connection
 */
typedef struct 
{
    int fd;				/**< File Descrtiptor*/
    int authOK;				/**< Authentication status */
} ConnectionData;

/**
 * \brief Authentication mode.
 *
 * The authentication mode says when password authentication
 * is needed. Autoproc knows three modes: no authentication,
 * authentication required for active operations, and
 * authentication always required.
 *
 */
enum AuthMode {
    AP_AUTH_NONE,      		/**< No Authentication required */
    AP_AUTH_CHANGE,    		/**< Authentication required for changing process states */
    AP_AUTH_ALL		       	/**< Authentication required for all operations */
};

int connection_check_auth_level(ConnectionData *cd, int level);
void connection_print(ConnectionData *cd, const char* msg);
void connection_println(ConnectionData *cd, const char* msg);
void connection_init(ConnectionData *cd) ;
void connection_printf(ConnectionData *cd, const char *format, ...) ;




#endif
