#include <stdlib.h>
#include <malloc.h>
#include <string.h>
#include "process_array.h"

#define INITIAL_ARRAY_SIZE 10


/**
 * \brief Creates and initializes a process array.
 * Creates a process array with an initial maximal size of 10.
 * \return Pointer to a new process array or 0.
 */
ProcessArray *process_array_create() 
{
    ProcessArray *new_proc_array;
    
    new_proc_array = malloc(sizeof(ProcessArray));
    if (new_proc_array != NULL)
    {
	new_proc_array->size = 0;
	new_proc_array->maxsize = 0;
	new_proc_array->pd = NULL;
	process_array_redim(new_proc_array, INITIAL_ARRAY_SIZE);
    }
    return new_proc_array;
}



/**
 * \brief Resizes a process array.
 */
void process_array_redim(ProcessArray *pa, int newsize)
{

    int i;
    int imax;
    
    ProcessData *newData;

    if ((newsize < 1) || (pa == NULL)) return;

    /* Create new array */
    newData = malloc(newsize * sizeof(ProcessData));
    if (newData == NULL) return;


    if (newData != NULL) {
    
	if (newsize > pa->size)
	    imax = pa->size;  /* shorten array */
	else
	    imax = newsize;   /* enlarge array */

	if (pa->pd != NULL)
	{
	    /* Copy old data to new array */
	    for(i=0;i<imax;i++)
		newData[i] = pa->pd[i];

	    /* Free old array */
	    free(pa->pd);
	}

	pa->size = imax;
	pa->maxsize = newsize;
	pa->pd = newData;
	
    } else {
	/* TODO print error message */
    }
   
}

/**
 * \brief Deeallocates a process array
 * Deallocates the process array itself and its data.
 * \param pa Process array.
 */
void process_array_free(ProcessArray *pa)
{
    free(pa->pd);
    free(pa);
};


/**
 * \brief Resets the process array's size
 * \param pa Process array.
 */
void process_array_clear(ProcessArray *pa) 
{
    pa->size = 0;
}


