#include "options.h"
#include <unistd.h>
#include <stdlib.h>
#include <stdio.h>
#include "log.h"

/**
 * \brief Sets default values to command-line options.
 */
void options_set_defaults(Options *opt) 
{
    opt->set_debug_enabled = 0;
    opt->set_user = 0;
    opt->set_config_file = 0;
    opt->set_ioperm = 0;
    opt->config_file[0] = 0;
    opt->debug_level = LOG_LEVEL_DEBUG;
    opt->user_name[0] = 0;
}

/**
 * \brief Allocates and initializes command-line options
 */
Options *options_create() 
{
    Options *result = NULL;
    result = (Options *)malloc(sizeof(Options));
    if (result != NULL) options_set_defaults(result);
    return result;
}

/**
 * \brief Reads Command-line options
 */
void options_read(Options *opt, int argc, char **argv) 
{
     int next_option;
    /* Get command line options */
    while( (next_option=getopt(argc,argv,"diu:c:D:")) != -1)
    {
	switch(next_option)
	{
	case 'd':
	    opt->set_debug_enabled = 1;
	    opt->debug_level = LOG_LEVEL_DEBUG;
	    break;
	case 'u':
	     opt->set_user = 1;
	    snprintf(opt->user_name, OPTIONS_LEN_USER_NAME, "%s", optarg);
	    break;
	case 'c':
	    opt->set_config_file = 1;
	    snprintf(opt->config_file, OPTIONS_LEN_CONFIG_FILE, "%s", optarg);
	    break;
	case 'D':
	    opt->set_debug_enabled = 1;
	    opt->debug_level = log_translate_string(optarg);
	    break;
	case 'i':
	    opt->set_ioperm=1;
	    break;
	default:
	    break;
	}
    }

}

/**
 * \brief Allocates options and processes the command line.
 * \param argc Number of arguments.
 * \param argv Arguments.
 * A combination of options_create and options_read.
 */
Options *options_create_from_args(int argc, char **argv) 
{
    Options *result;
    result = options_create();
    if (result != NULL) options_read(result, argc, argv);
    return result;
}

