/* -*-C-*- */
#ifndef PROCESS_CONTROL_H
#define PROCESS_CONTROL_H

/**
 * \file process_control.h 
 * \brief Process control.
 *
 * This module contains functions for process control and
 * control statistics. The process control operates on an array
 * of processes, which is assigned by process_control_init().
 *
 * The process control is designed to run as a pth thread.
 * The thread, process_control_update_thread(), gathers
 * process and CPU information from the system,
 * and then checks if processes are
 * in their required states and stops or restarts processes
 * if necessary.
 */

#include <sys/types.h>
#include "array.h"

/**
 * \brief Data for process control statistics.
 */
typedef struct 
{
    int nProcesses;	/**< Number of processes */
    int nActive;	/**< Number of currently active processes */
    int nInactive;	/**< Number of currently inactive processes */
    int nErrors;	/**< Number of processes which could not be started */
    int nRestarts;	/**< Number of process restarts since last init */
    int nCrashes;	/**< Number of process crashes since last init */
    double cpuload;	/**< Sum of CPU loads of all processes */
} ControlStatistics;

void process_control_print_list(int fd);
void *process_control_update_thread(void *arg);
void process_control_initialize(Array *procArray);
void process_control_print_statistics(int fd);
void process_control_reset_process_statistics(char **tags, int nTags);
void process_control_reset_all_process_statistics();
int process_control_release_mutex();
int process_control_acquire_mutex();
void process_control_start_processes(char **tags, int nTags, int execInit) ;
void process_control_stop_processes(char **tags, int nTags) ;
void process_control_start_all_processes(int execInit) ;
void process_control_stop_all_processes() ;
void process_control_close_all() ;
void process_control_notify_termination(pid_t pid);
void process_control_shutdown_processes(char **tags, int nTags) ;
void process_control_shutdown_all_processes() ;

#endif
    
    
