/* -*-C-*- */
#ifndef PROCESS_INFO_H
#define PROCESS_INFO_H

#define PROCESS_INFO_LENGTH_COMMAND 512 /**< Length of command */

/**
 * \file process_info.h
 * \brief Functions to read process information from the system.
 */

/**
 * \brief Structure for process information.
 * This structure contains Linux process information as read from the /proc filesystem.
 */
typedef struct
{
    int pid;				/**< Process ID  */
    char command[PROCESS_INFO_LENGTH_COMMAND]; /**< Executable file name  */
    char state;				/**< Process state.
					 * 'R' : running,
					 * 'S' : Sleeping,
					 * 'D' : waiting in uniterruptible disk sleep,
					 * 'Z' : Zombie,
					 * 'T' : traced/stopped,
					 * 'W' : paging
					 */
    int ppid;				/**< Parent process ID  */
    int pgrp;				/**< Process group ID  */
    int session;			/**< Session ID  */
    int tty;				/**< Number ot the TTY the process uses */
    int tpgid;				/**< TTY owner's Process ID  */
    unsigned long flags;			/**< Kernel flags of the process  */
    unsigned long minflt;		/**< Number of minor page faults  */
    unsigned long cminflt;		/**< Number of children's minor page faults  */
    unsigned long majflt;		/**< Number of major page faults (swapping)  */
    unsigned long cmajflt;		/**< Number of children's major page faults  */
    unsigned long utime;				/**< Time in jiffies (=10ms) spent in user mode  */
    unsigned long stime;				/**< Time in jiffies spent in system mode  */
    long cutime;				/**< Time in jiffies that children spent in user mode */
    long cstime;				/**< Time in jiffies that children spent in system mode */
    long priority;			/**< The standard nice value,  plus  fifteen. */
    long nice;				/**< The nice value. 19 to -19. */
    long timeout;		/**< Not used anymore. Always 0.  */
    long itrealvalue;		/**< The  time  in  jiffies before the next
					 * SIGALRM is sent to the process due to an
					 * interval timer.
					 */
    unsigned long starttime;		/**<  The time in jiffies  the  process
					 * started  after  system  boot.
					 */
    unsigned long vsize;		/**< Virtual memory size in bytes.  */
    long rss;				/**< Resident Set Size  */
    unsigned long rlim;			/**< RSS limit */
    unsigned long startcode;		/**< The address above which program text can run.*/
    unsigned long endcode;		/**< The address below which program text can run. */
    unsigned long startstack;		/**< The address of the start of the stack. */
    unsigned long kstkesp;		/**< The current value of esp (stack pointer) */
    unsigned long kstkeip;		/**< The current EIP (instruction pointer) */
    unsigned long signal;		/**< The bitmap of pending signals (usually 0). */
    unsigned long blocked;		/**<  The  bitmap of blocked signals */
    unsigned long sigignore;		/**< The bitmap of ignored signals. */
    unsigned long sigcatch;		/**< The bitmap of catched signals.  */
    unsigned long wchan;		/**< The channel in which the  process  is  waiting. */
    
    /* ON NEWER KERNELS ONLY - not used by autpprocd */
    /*
      unsigned long nswap;	Number of pages swapped	
      unsigned long cnswap;	Cumulative nswap for child processes.
      int exit_signal;		Signal to be sent to parent when we die.
      int processor;		CPU number last executed on.
    */

    unsigned long starttime_sec;	/**< Start time in seconds, calculated by autoprocd */
    unsigned int cputime;		/**< CPU time which counts in statistics, calculated by autoprocd */
} ProcessInfo;

int process_info_update(int pid, ProcessInfo *pi);

#endif




