/* -*-C-*- */
#ifndef SHELL_COMMAND_H
#define SHELL_COMMAND_H

#include <sys/types.h>
#include "environment.h"
#include "array.h"

#define SHELL_COMMAND_LEN_NAME 30		/**< Length of field name  */
#define SHELL_COMMAND_LEN_CMD 256		/**< Length of field cmd  */
#define SHELL_COMMAND_LEN_WPATH 256		/**< Length of field wpath */

/**
 * \file shell_command.h
 * \brief Functions related with shell commands.
 * This module defines the structure ShellCommand
 * and contains functions which manipulate that
 * structure or start a shell command.
 */

/**
 * \brief A structure which describes a shell command.
 */
typedef struct
{
    char name[SHELL_COMMAND_LEN_NAME];		/**< Unique identifier  */
    char cmd[SHELL_COMMAND_LEN_CMD];		/**< Executable path */
    char wpath[SHELL_COMMAND_LEN_WPATH];	/**< working directory */    
    uid_t uid;				/**< User ID  at execution  */
    gid_t gid;				/**< Group ID at execution */
    Array *environment;		/**< Array of environment variables */ 
    
} ShellCommand;

ShellCommand *shell_command_create();
void shell_command_destroy(void *data);
void shell_command_set_defaults(ShellCommand *sd);
int shell_command_execute(ShellCommand *sd);
void shell_command_set_attribute(ShellCommand *sd, const char *attr, const char *value);
void shell_command_add_environment(ShellCommand *pd, const char *attr, const char *value);


ShellCommand *shell_command_array_find(Array *array, const char *name);


#endif    
    

