#include "sys_util.h"
#include <stdlib.h>
#include <unistd.h>
#include <string.h>
#include <pwd.h>
#include <grp.h>
#include <sys/types.h>
#include "string_util.h"


/**
 * \brief Finds the user ID and group ID for a specified user name.
 * 
 * \param user User name to look for.
 * \param uid Pointer to store UID.
 * \param gid Pointer to store GID.
 *
 * \return
 * <ul>
 *	<li>0 if user not found</li>
 *      <li>1 id user found</li>
 * </ul>
 */
int sys_util_findUID(const char *user, uid_t *uid, gid_t *gid)
{
    struct passwd *pw;
    int rv;

    rv = 0;
    
    setpwent();
    while((pw = getpwent()) != NULL)
    {
	if (!strcmp(user, pw->pw_name))
	{
	    *gid = pw->pw_gid;
	    *uid = pw->pw_uid;
	    rv = 1;
	    break;
	}
    }
    endpwent();
    return rv;
}

/**
 * \brief Finds the group ID for a specified group name.
 *
 * \param group  Group name to look for.
 * \param gid pointer to a gid_t where the result is stored.
 *
 * \return
 * <ul>
 *	<li>0 if group not found</li>
 *      <li>1 if group found</li>
 * </ul>
 */
int sys_util_findGID(const char *group, gid_t *gid)
{
    struct group *gr;
    int rv;

    rv = 0;
    
    setgrent();
    while((gr = getgrent()) != NULL)
    {
	if (!strcmp(group, gr->gr_name))
	{
	    *gid = gr->gr_gid;
	    rv = 1;
	    break;
	}
    }
    endgrent();
    return rv;
}

/**
 * \brief Finds the home directory for a specified UID.
 *
 * \param uid User ID
 * \param dest Pointer to result string buffer.
 * \param mxlen Length of dest
 */
int sys_util_findHomeDir(uid_t uid, char *dest, int mxlen)
{
    struct passwd *pw;
    int rv;

    rv =0;
    setpwent();
    while((pw = getpwent()) != NULL)
    {
	if (pw->pw_uid == uid)
	{
	    string_util_strncpy(dest, pw->pw_dir, mxlen);
	    rv = 1;
	    break;
	}
    }
    endpwent();
    
    return rv;
}
