#include <stdio.h>
#include <stdlib.h>
#include <array.h>

#define ARRAY_SIZE 1000

static int alloc_counter = 0;

static void *allocator_func(double value) 
{
    double *newElement;
    newElement = (double *)malloc(sizeof(double));
    *newElement = value;
    alloc_counter++;
    return (void *)newElement;
}

static void destructor_func(void *element) 
{
    free(element);
    alloc_counter--;
}

static int compareFunction(void *element, void *user_data) 
{
    return (*((double *)element) == *((double *)user_data));
}

int main(int argc, char **argv) 
{
    int i;
    double compareValue = 43;
    double *foundElement;
    
    
    Array *array = array_create();
    for (i=0; i<ARRAY_SIZE; i++) {
	array_append(array,allocator_func((double)i));
    }

    if (array->max_length < array->length) printf("Allocation failed\n");
    if (array->length != ARRAY_SIZE) printf("Wrong array length %d != %d\n", array->length, ARRAY_SIZE);


    for (i=0; i<ARRAY_SIZE; i++) {
	compareValue = (double) i;
	foundElement = array_find_equals(array,compareFunction,&compareValue);

	if (foundElement == NULL)
	    printf("No Element found %lf\n", compareValue);
	else if (*foundElement != compareValue)
	    printf ("Compare: %lf != %lf\n", *foundElement, compareValue);
    }
    
    array_clear(array, destructor_func);

    if (array->length != 0) printf("Clear failed.\n");
    if (alloc_counter != 0) printf("Alloc Counter != 0 after clear! %d\n", alloc_counter);
    
    
    for (i=0; i<ARRAY_SIZE; i++) {
	array_append(array,allocator_func((double)i));
    }
    if (array->max_length < array->length) printf("Allocation failed\n");
    if (array->length != ARRAY_SIZE) printf("Wrong array length %d != %d\n", array->length, ARRAY_SIZE);

    for (i=0; i<ARRAY_SIZE; i++) {
	array_remove(array,0, destructor_func);
	if (array->length != ARRAY_SIZE-i-1) printf("Remove failed. %d != %d\n", array->length, ARRAY_SIZE-i-1);
    }
    if (array->length != 0) printf("Remove elements failed.\n");
    if (alloc_counter != 0) printf("Alloc Counter != 0 after removing elements! %d\n", alloc_counter);

    for (i=0; i<ARRAY_SIZE; i++) {
	array_append(array,allocator_func((double)i));
    }
    if (array->max_length < array->length) printf("Allocation failed\n");
    if (array->length != ARRAY_SIZE) printf("Wrong array length %d != %d\n", array->length, ARRAY_SIZE);

    array_destroy(array, destructor_func);
    if (array->length != 0) printf("Clear failed.\n");
    if (alloc_counter != 0) printf("Alloc Counter != 0 after clear! %d\n", alloc_counter);

    
}
